@@ -7,6 +7,9 @@ from ._constant import EVALUATE_URL
 @typechecked
 def evaluate(e : float, p : float):
 
+    if e < 0:
+        raise ValueError("Young's modulus (e) must be positive")
+
     payload = {
         "e": e,
         "p": p
